@@ -5,10 +5,11 @@
 Register the conda env spec for environment.yml files.
 """
 
-from .. import CondaEnvironmentSpecifier, hookimpl
+from .. import hookimpl
+from ..types import CondaEnvironmentSpecifier
 
 
-@hookimpl
+@hookimpl(tryfirst=True)
 def conda_environment_specifiers():
     from ...env.specs.yaml_file import YamlFileSpec
 
